pub struct Configuration {
Show 16 fields pub log_level: Option<String>, pub mode: TrackerMode, pub db_driver: DatabaseDriver, pub db_path: String, pub announce_interval: u32, pub min_announce_interval: u32, pub max_peer_timeout: u32, pub on_reverse_proxy: bool, pub external_ip: Option<String>, pub tracker_usage_statistics: bool, pub persistent_torrent_completed_stat: bool, pub inactive_peer_cleanup_interval: u64, pub remove_peerless_torrents: bool, pub udp_trackers: Vec<UdpTracker>, pub http_trackers: Vec<HttpTracker>, pub http_api: HttpApi,
}

Fields

log_level: Option<String>mode: TrackerModedb_driver: DatabaseDriverdb_path: Stringannounce_interval: u32min_announce_interval: u32max_peer_timeout: u32on_reverse_proxy: boolexternal_ip: Option<String>tracker_usage_statistics: boolpersistent_torrent_completed_stat: boolinactive_peer_cleanup_interval: u64remove_peerless_torrents: booludp_trackers: Vec<UdpTracker>http_trackers: Vec<HttpTracker>http_api: HttpApi

Implementations

source

impl Configuration

source

pub fn get_ext_ip(&self) -> Option<IpAddr>

source

pub fn load_from_file(path: &str) -> Result<Configuration, Error>

Errors

Will return Err if path does not exist or has a bad configuration.

source

pub fn load_from_env_var( config_env_var_name: &str ) -> Result<Configuration, Error>

Errors

Will return Err if the environment variable does not exist or has a bad configuration.

source

pub fn save_to_file(&self, path: &str) -> Result<(), Error>

Errors

Will return Err if filename does not exist or the user does not have permission to read it.