pub struct HttpTracker {
    pub enabled: bool,
    pub bind_address: String,
    pub ssl_enabled: bool,
    pub ssl_cert_path: Option<String>,
    pub ssl_key_path: Option<String>,
}
Configuration for each HTTP tracker.

Fields

enabled: bool

Weather the HTTP tracker is enabled or not.

bind_address: String

The address the tracker will bind to. The format is ip:port, for example 0.0.0.0:6969. If you want to listen to all interfaces, use 0.0.0.0. If you want the operating system to choose a random port, use port 0.

ssl_enabled: bool

Weather the HTTP tracker will use SSL or not.

ssl_cert_path: Option<String>

Path to the SSL certificate file. Only used if ssl_enabled is true.

ssl_key_path: Option<String>

Path to the SSL key file. Only used if ssl_enabled is true.