pub struct UdpTracker {
    pub enabled: bool,
    pub bind_address: String,
}
Configuration for each UDP tracker.

Fields

enabled: bool

Weather the UDP tracker is enabled or not.

bind_address: String

The address the tracker will bind to. The format is ip:port, for example 0.0.0.0:6969. If you want to listen to all interfaces, use 0.0.0.0. If you want the operating system to choose a random port, use port 0.